@@ -1,7 +1,7 @@
 #!perl
-# $Id: probe_mecab.pl 6 2006-05-03 17:07:16Z daisuke $
+# $Id: /mirror/perl/Text-MeCab/trunk/tools/probe_mecab.pl 38046 2008-01-06T12:44:20.889262Z daisuke  $
 #
-# Copyright (c) 2006 Daisuke Maki <dmaki@cpan.org>
+# Copyright (c) 2006-2008 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 use strict;
@@ -9,8 +9,11 @@ use File::Spec;
 
 my $interactive = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT)) ;
 my($version, $cflags, $libs);
+
+$cflags = '';
+
 # Save the poor puppies that run on Windows
-if ($^O eq 'Win32') {
+if ($^O eq 'MSWin32') {
     print <<EOM;
 You seem to be running on an environment that may not have mecab-config
 available. This script uses mecab-config to auto-probe 
@@ -23,21 +26,21 @@ Since we can't auto-probe, you should specify the above three to proceed
 with compilation:
 EOM
 
-    print "Version of libmecab that you are compiling against (required)? [] ";
+    print "Version of libmecab that you are compiling against (e.g. 0.90)? (REQUIRED) [] ";
     $version = <STDIN>;
     chomp($version);
-    die "no version specified!" unless $version;
+    die "no version specified! cowardly refusing to proceed." unless $version;
 
-    print "Additional compiler flags? [] ";
+    print "Additional compiler flags (e.g. -DWIN32 -Ic:\\path\\to\\mecab\\sdk)? [] ";
     if ($interactive) {
         $cflags = <STDIN>;
         chomp($cflags);
     }
 
-    print "Additional linker flags? [] ";
+    print "Additional linker flags (e.g. -lc:\\path\\to\\mecab\\sdk\\libmecab.lib? [] ";
     if ($interactive) {
         $libs = <STDIN>;
-        chomp($cflags);
+        chomp($libs);
     }
 } else {
     # try probing in places where we expect it to be
@@ -51,15 +54,15 @@ EOM
     }
     
     print "Path to mecab config? [$mecab_config] ";
-    my $tmp = <STDIN>;
-    chomp $tmp;
-    if ($tmp) {
-        $mecab_config = $tmp;
+    if ($interactive) {
+        my $tmp = <STDIN>;
+        chomp $tmp;
+        if ($tmp) {
+            $mecab_config = $tmp;
+        }
     }
     
     if (!-f $mecab_config || ! -x _) {
-    
-    
         print STDERR "Can't proceed without mecab-config. Aborting...\n";
         exit 1;
     }
@@ -82,8 +85,39 @@ if ($version < 0.90) {
 }
 
 my($major, $minor, $micro) = map { s/\D+//g; $_ } split(/\./, $version);
-$cflags .= " -DMECAB_MAJOR_VERSION=$major -DMECAB_MINOR_VERSION=$minor";
-print "Using compiler flags '$cflags'...\n";
-print "Using linker flags '$libs'...\n";
 
-return { cflags => $cflags, libs => $libs };
\ No newline at end of file
+$cflags .= " -DMECAB_MAJOR_VERSION=$major -DMECAB_MINOR_VERSION=$minor";
+
+# remove whitespaces from beginning and ending of strings
+$cflags =~ s/^\s+//;
+$cflags =~ s/\s+$//;
+
+print "Using compiler flags '$cflags'...\n";
+
+if ($libs) {
+    $libs =~ s/^\s+//;
+    $libs =~ s/\s+$//;
+    print "Using linker flags '$libs'...\n";
+} else {
+    print "No linker flags specified\n";
+}
+
+my $encoding = 'utf-8';
+print 
+    "Text::MeCab needs to know what encoding you built your dictionary with\n",
+    "to properly execute tests.\n",
+    "\n",
+    "Encoding of your mecab dictionary? (shift_jis, euc-jp, utf-8) [$encoding] "
+;
+
+if ($interactive) {
+    my $input = <STDIN>;
+    chomp $input;
+    if ($input) {
+        $encoding = $input;
+    }
+}
+
+print "Using $encoding as your dictionary encoding\n";
+
+return { version => $version, cflags => $cflags, libs => $libs, encoding => $encoding };
\ No newline at end of file
